@@ -3,6 +3,7 @@
  * flint.cpp - FLash INTerface
  *
  * Copyright (c) 2013 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -41,10 +42,10 @@
 
 #include "flint.h"
 
-//Globals:
-Flint *gFlint = NULL;
-extern FILE *flint_log_fh;
-//signal handler section
+// Globals:
+Flint* gFlint = NULL;
+extern FILE* flint_log_fh;
+// signal handler section
 
 #define BURN_INTERRUPTED 0x1234
 
@@ -53,44 +54,45 @@ void TerminationHandler(int signum);
 #ifdef __WIN__
 #include <windows.h>
 
-static BOOL CtrlHandler( DWORD fdwCtrlType )
+static BOOL CtrlHandler(DWORD fdwCtrlType)
 {
     switch (fdwCtrlType)
     {
-    // Handle the CTRL-C signal.
-    case CTRL_C_EVENT:
-    // CTRL-CLOSE: confirm that the user wants to exit.
-    case CTRL_CLOSE_EVENT:
-    // Pass other signals to the next handler.
-    case CTRL_BREAK_EVENT:
-    case CTRL_LOGOFF_EVENT:
-    case CTRL_SHUTDOWN_EVENT:
-        TerminationHandler(SIGINT);
-        return TRUE;
+        // Handle the CTRL-C signal.
+        case CTRL_C_EVENT:
+        // CTRL-CLOSE: confirm that the user wants to exit.
+        case CTRL_CLOSE_EVENT:
+        // Pass other signals to the next handler.
+        case CTRL_BREAK_EVENT:
+        case CTRL_LOGOFF_EVENT:
+        case CTRL_SHUTDOWN_EVENT:
+            TerminationHandler(SIGINT);
+            return TRUE;
 
-    default:
-        return FALSE;
+        default:
+            return FALSE;
     }
 }
 
 #endif
 
-
 void TerminationHandler(int signum)
 {
     static volatile sig_atomic_t fatal_error_in_progress = 0;
 
-    if (fatal_error_in_progress) {
+    if (fatal_error_in_progress)
+    {
         raise(signum);
     }
     fatal_error_in_progress = 1;
 
     write_result_to_log(BURN_INTERRUPTED, "");
     close_log();
-    if (gFlint != NULL) {
+    if (gFlint != NULL)
+    {
         printf("\n Received signal %d. Cleaning up ...\n", signum);
         fflush(stdout);
-        //sleep(1); // Legacy from the Old Flint
+        // sleep(1); // Legacy from the Old Flint
         gFlint->GetSubCommands()[gFlint->GetFlintParams().cmd]->cleanInterruptedCommand();
         delete gFlint;
         gFlint = NULL;
@@ -100,31 +102,42 @@ void TerminationHandler(int signum)
     raise(signum);
 }
 
+#ifdef __WIN__
+#define SIGNAL_NUM 3
+static int signalList[SIGNAL_NUM] = {SIGINT, SIGTERM, SIGABRT};
+#else
+#define SIGNAL_NUM 4
+static int signalList[SIGNAL_NUM] = {SIGINT, SIGTERM, SIGPIPE, SIGHUP};
+#endif
 
 void initHandler()
 {
 #ifdef __WIN__
-#define SIGNAL_NUM 3
-    int signalList[SIGNAL_NUM] = {SIGINT, SIGTERM, SIGABRT};
-    SetConsoleCtrlHandler( (PHANDLER_ROUTINE) CtrlHandler, true );
-#else
-#define SIGNAL_NUM 4
-    int signalList[SIGNAL_NUM] = {SIGINT, SIGTERM, SIGPIPE, SIGHUP};
+    SetConsoleCtrlHandler((PHANDLER_ROUTINE)CtrlHandler, true);
 #endif
 
-    //set the signal handler
-    for (int i = 0; i < SIGNAL_NUM; i++) {
+    // set the signal handler
+    for (int i = 0; i < SIGNAL_NUM; i++)
+    {
         void (*prevFunc)(int);
         prevFunc = signal(signalList[i], TerminationHandler);
-        if (prevFunc == SIG_ERR) {
+        if (prevFunc == SIG_ERR)
+        {
             printf("-E- failed to set signal Handler.");
             exit(FLINT_FAILED);
         }
     }
 }
 
-//End of signal handler section.
+void ignoreSignals()
+{
+    for (int i = 0; i < SIGNAL_NUM; i++)
+    {
+        signal(signalList[i], SIG_IGN);
+    }
+}
 
+// End of signal handler section.
 
 map_sub_cmd_t_to_subcommand Flint::initSubcommandMap()
 {
@@ -143,6 +156,7 @@ map_sub_cmd_t_to_subcommand Flint::initSubcommandMap()
 #ifndef EXTERNAL
     cmdMap[SC_Smg] = new SmgSubCommand();
     cmdMap[SC_Set_Vpd] = new SetVpdSubCommand();
+    cmdMap[SC_Set_Cert_Chain] = new SetCertChainSubCommand();
     cmdMap[SC_Fix_Img] = new FiSubCommand();
     cmdMap[SC_Extract_4MB_Image] = new Extract4MBImageSubCommand();
 #endif
@@ -170,9 +184,9 @@ map_sub_cmd_t_to_subcommand Flint::initSubcommandMap()
     cmdMap[SC_Set_Forbidden_Versions] = new SetForbiddenVersionsSubCommand();
     cmdMap[SC_Image_Reactivation] = new ImageReactivationSubCommand();
     cmdMap[SC_RSA_Sign] = new SignRSASubCommand();
-    cmdMap[SC_Binary_Compare] = new  BinaryCompareSubCommand();
-    cmdMap[SC_Import_Hsm_Key] = new  ImportHsmKeySubCommand();
-#if !defined(UEFI_BUILD) && !defined(NO_OPEN_SSL)
+    cmdMap[SC_Binary_Compare] = new BinaryCompareSubCommand();
+    cmdMap[SC_Import_Hsm_Key] = new ImportHsmKeySubCommand();
+#ifndef NO_OPEN_SSL
     cmdMap[SC_Export_Public_Key] = new ExportPublicSubCommand();
 #endif
     return cmdMap;
@@ -184,7 +198,6 @@ void Flint::deInitSubcommandMap(map_sub_cmd_t_to_subcommand cmdMap)
         delete it->second;
 }
 
-
 Flint::Flint() :
     CommandLineRequester(FLINT_DISPLAY_NAME " [OPTIONS] <command> [Parameters]"),
     _flintParams(),
@@ -199,51 +212,64 @@ Flint::~Flint()
     deInitSubcommandMap(_subcommands);
 }
 
-FlintStatus Flint::run(int argc, char *argv[])
+FlintStatus Flint::run(int argc, char* argv[])
 {
-    //Step1 parse input
-    //There are some memory allocations parseCmdLine
+    // Step1 parse input
+    // There are some memory allocations parseCmdLine
     ParseStatus status;
-    try {
+    try
+    {
         status = this->parseCmdLine(argc, argv);
-    } catch (exception& e) {
+    }
+    catch (exception& e)
+    {
         cout << "-E- " << e.what() << endl;
         return FLINT_FAILED;
     }
-    if (status == PARSE_OK_WITH_EXIT) {
+    if (status == PARSE_OK_WITH_EXIT)
+    {
         return FLINT_SUCCESS;
-    } else if (status == PARSE_ERROR || status == PARSE_ERROR_SHOW_USAGE) {
-        if (string(_cmdParser.GetErrDesc()).length() > 0) {
+    }
+    else if (status == PARSE_ERROR || status == PARSE_ERROR_SHOW_USAGE)
+    {
+        if (string(_cmdParser.GetErrDesc()).length() > 0)
+        {
             cout << "-E- " << this->_cmdParser.GetErrDesc() << endl;
         }
         return FLINT_FAILED;
     }
 
-    if (_flintParams.cmd == SC_No_Cmd && !_flintParams.clear_semaphore) {
+    if (_flintParams.cmd == SC_No_Cmd && !_flintParams.clear_semaphore)
+    {
         cout << FLINT_NO_COMMAND_ERROR << endl;
         return FLINT_FAILED;
     }
-    if (_flintParams.clear_semaphore) {
-        if (_flintParams.cmd != SC_No_Cmd) {
+    if (_flintParams.clear_semaphore)
+    {
+        if (_flintParams.cmd != SC_No_Cmd)
+        {
             printf(FLINT_CLEAR_SEM_CMD_ERROR);
             return FLINT_FAILED;
         }
         _flintParams.cmd = SC_Clear_Sem;
     }
 
-    //TODO: adrianc: remove use_fw flag and this condition before MFT-4.1.0
-    if (_flintParams.use_fw && _flintParams.override_cache_replacement) {
+    // TODO: adrianc: remove use_fw flag and this condition before MFT-4.1.0
+    if (_flintParams.use_fw && _flintParams.override_cache_replacement)
+    {
         printf("-E- flags --use_fw and --override_cache_replacement/-ocr cannot be specified simultaneously");
         return FLINT_FAILED;
     }
 
-    // Step 2 save argv as a single cmd string in flint params for the log functionallity
-    for (int i = 0; i < argc; i++) {
+    // Step 2 save argv as a single cmd string in flint params for the log functionality
+    for (int i = 0; i < argc; i++)
+    {
         _flintParams.fullCmd = _flintParams.fullCmd + argv[i] + " ";
     }
-    //TODO: Step 3 check flintParams for contradictions?
-    //Step 4 execute command from the correct subcommand class
-    if (_subcommands.count(_flintParams.cmd) == 0) {
+    // TODO: Step 3 check flintParams for contradictions?
+    // Step 4 execute command from the correct subcommand class
+    if (_subcommands.count(_flintParams.cmd) == 0)
+    {
         // should not be reached
         printf("-E- FATAL: command object not found.");
         return FLINT_FAILED;
@@ -252,15 +278,16 @@ FlintStatus Flint::run(int argc, char *argv[])
     return _subcommands[_flintParams.cmd]->executeCommand();
 }
 
-
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
     initHandler();
     try
     {
         gFlint = new Flint();
         FlintStatus rc = gFlint->run(argc, argv);
-        if (gFlint) {
+        if (gFlint)
+        {
+            ignoreSignals(); // clean-up should be signal free, prevent possible clean-up re-entry
             delete gFlint;
             gFlint = NULL;
         }
