@@ -3,6 +3,7 @@
  * flint_params.cpp - FLash INTerface
  *
  * Copyright (c) 2013 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -52,11 +53,12 @@ FlintParams::FlintParams()
     device_specified = false;
     blank_guids = false;
     clear_semaphore = false;
-    quick_query = true;  //should now be true by default
+    quick_query = true; // should now be true by default
     next_boot_fw_ver = false;
     low_cpu = false;
     skip_rom_query = false;
     image_specified = false;
+    nonencrypted_image_specified = false;
     mfa2_specified = false;
     nofs = false;
     allow_psid_change = false;
@@ -86,6 +88,8 @@ FlintParams::FlintParams()
     flash_params.num_of_flashes = 0;
     flash_params.log2size = 0;
     use_dev_img_info = false;
+    ignore_crc_check = false;
+    hexdump_format = false;
     skip_ci_req = false;
     use_dev_rom = false;
     privkey_specified = false;
@@ -114,11 +118,8 @@ FlintParams::FlintParams()
     downstream_device_ids_specified = false;
     download_transfer = false;
     // if no delay specified, use minimal delay to avoid disconnection in case of activating the connect port
-    activate_delay_sec = 1; 
+    activate_delay_sec = 1;
     openssl_engine_usage_specified = false;
 }
 
-FlintParams::~FlintParams()
-{
-
-}
+FlintParams::~FlintParams() {}
