@@ -3,6 +3,7 @@
  * subcommands.h - FLash INTerface
  *
  * Copyright (c) 2013 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -56,14 +57,15 @@ using namespace std;
 #include "mlxarchive/mlxarchive_mfa2_utils.h"
 using namespace mfa2;
 #endif
-//we might need to close the log from the main program in case of interrupt
+// we might need to close the log from the main program in case of interrupt
 void close_log();
 void print_time_to_log();
-int print_line_to_log(const char *format, ...);
-int write_cmd_to_log(char *av[], int ac, CommandType cmd, bool write = true);
-int write_result_to_log(int is_failed, const char *err_msg, bool write = true);
+int print_line_to_log(const char* format, ...);
+int write_cmd_to_log(char* av[], int ac, CommandType cmd, bool write = true);
+int write_result_to_log(int is_failed, const char* err_msg, bool write = true);
 
-typedef enum what_to_ver {
+typedef enum what_to_ver
+{
     Wtv_Img,
     Wtv_Dev,
     Wtv_Dev_And_Img,
@@ -72,23 +74,20 @@ typedef enum what_to_ver {
 } what_to_ver_t;
 /*Subcommand classes:*/
 
-
-
-
 #define FLINT_ERR_LEN 1024
 
 class SubCommand
 {
 protected:
-    FwOperations *_fwOps;
-    FwOperations *_imgOps;
-    FBase *_io;
+    FwOperations* _fwOps;
+    FwOperations* _imgOps;
+    FBase* _io;
 
     what_to_ver_t _v;
     int _maxCmdParamNum;
     int _minCmdParamNum;
     FlintParams _flintParams;
-    //info about the Subcommand
+    // info about the Subcommand
     string _name;
     string _desc;
     string _extendedDesc;
@@ -104,29 +103,29 @@ protected:
 #ifndef NO_MSTARCHIVE
     MFA2* _mfa2Pkg;
 #endif
-    //Methods that are commonly used in the various subcommands:
-    //TODO: add middle classes and segregate as much of these common methods between these classes
+    // Methods that are commonly used in the various subcommands:
+    // TODO: add middle classes and segregate as much of these common methods between these classes
 
-    virtual bool verifyParams() {return true;};
+    virtual bool verifyParams() { return true; };
     bool basicVerifyParams();
-    void initDeviceFwParams(char *errBuff, FwOperations::fw_ops_params_t& fwParams);
+    void initDeviceFwParams(char* errBuff, FwOperations::fw_ops_params_t& fwParams);
     FlintStatus openOps(bool ignoreSecurityAttributes = false, bool ignoreDToc = false);
     FlintStatus openIo();
     virtual FlintStatus preFwOps(bool ignoreSecurityAttributes = false, bool ignoreDToc = false);
     virtual FlintStatus preFwAccess();
 
-    bool getRomsInfo(FBase *io, roms_info_t& romsInfo);
+    bool getRomsInfo(FBase* io, roms_info_t& romsInfo);
     void displayOneExpRomInfo(const rom_info_t& info);
-    void displayExpRomInfo(const roms_info_t& romsInfo, const char *preStr);
+    void displayExpRomInfo(const roms_info_t& romsInfo, const char* preStr);
     string getExpRomVerStr(const rom_info_t& info);
     string getRomProtocolStr(u_int8_t proto);
     string getRomSuppCpuStr(u_int8_t suppCpu);
     u_int32_t getUserChoice(u_int32_t maximumValue);
-    static int verifyCbFunc(char *str);
-    static int CbCommon(int completion, char *preStr, char *endStr = NULL);
+    static int verifyCbFunc(char* str);
+    static int CbCommon(int completion, char* preStr, char* endStr = NULL);
     static int burnCbFs2Func(int completion);
     static int burnCbFs3Func(int completion);
-    static int advProgressFunc(int completion, const char *stage, prog_t type, int *unknownProgress);
+    static int advProgressFunc(int completion, const char* stage, prog_t type, int* unknownProgress);
     static int burnBCbFunc(int completion);
     static int vsdCbFunc(int completion);
     static int setKeyCbFunc(int completion);
@@ -135,44 +134,69 @@ protected:
     static int wbCbFunc(int completion);
     static int resetCfgCbFunc(int completion);
 
-    bool printGuidLine(guid_t *new_guids, guid_t *old_guids, int guid_index);
-    bool printMacLine(guid_t *new_guids, guid_t *old_guids, int mac_index);
-    bool printGUIDsFunc(guid_t guids[GUIDS], guid_t macs[MACS], guid_t old_guids[GUIDS], \
-                        guid_t old_macs[MACS], bool print_guids, bool print_macs, int portNum, bool old_guid_fmt);
-    bool reportGuidChanges(guid_t *new_guids, guid_t *new_macs, \
-                           guid_t *old_guids, guid_t *old_macs, bool printGuids, \
-                           bool printMacs, int guidNum);
-    bool checkGuidsFlags(u_int16_t devType, u_int8_t fwType,
-                         bool guidsSpecified, bool macsSpecified, bool uidSpecified, bool ibDev, bool ethDev);
+    bool printGuidLine(guid_t* new_guids, guid_t* old_guids, int guid_index);
+    bool printMacLine(guid_t* new_guids, guid_t* old_guids, int mac_index);
+    bool printGUIDsFunc(guid_t guids[GUIDS],
+                        guid_t macs[MACS],
+                        guid_t old_guids[GUIDS],
+                        guid_t old_macs[MACS],
+                        bool print_guids,
+                        bool print_macs,
+                        int portNum,
+                        bool old_guid_fmt);
+    bool reportGuidChanges(guid_t* new_guids,
+                           guid_t* new_macs,
+                           guid_t* old_guids,
+                           guid_t* old_macs,
+                           bool printGuids,
+                           bool printMacs,
+                           int guidNum);
+    bool checkGuidsFlags(u_int16_t devType,
+                         u_int8_t fwType,
+                         bool guidsSpecified,
+                         bool macsSpecified,
+                         bool uidSpecified,
+                         bool ibDev,
+                         bool ethDev);
     void printMissingGuidErr(bool ibDev, bool ethDev);
 
     bool extractUIDArgs(std::vector<string>& cmdArgs, u_int8_t numOfGuids[2], u_int8_t stepSize[2]);
     bool extractValuesFromString(string valStr, u_int8_t values[2], string origArg);
     bool getGUIDFromStr(string str, guid_t& guid, string prefixErr = "");
-    bool  getPasswordFromUser(const char *preStr, char buffer[MAX_PASSWORD_LEN + 1]);
-    bool askUser(const char *question = NULL, bool printAbrtMsg = true);
+    bool getPasswordFromUser(const char* preStr, char buffer[MAX_PASSWORD_LEN + 1]);
+    bool askUser(const char* question = NULL, bool printAbrtMsg = true);
 
     bool isCmdSupportLog();
     void openLog();
-    inline void closeLog() {close_log();}
-    //print errors to an err buff, log if needed and stdout
-    void reportErr(bool shouldPrint, const char *format, ...);
+    inline void closeLog() { close_log(); }
+    // print errors to an err buff, log if needed and stdout
+    void reportErr(bool shouldPrint, const char* format, ...);
     bool readFromFile(const string& filePath, std::vector<u_int8_t>& buff);
     bool getFileSize(const string& filePath, long& fileSize);
     bool writeToFile(string filePath, const std::vector<u_int8_t>& buff);
-    FlintStatus writeImageToFile(const char *file_name, u_int8_t *data, u_int32_t length);
+    FlintStatus writeImageToFile(const char* file_name, u_int8_t* data, u_int32_t length);
 
-    bool dumpFile(const char *confFile, std::vector<u_int8_t>& data, const char *sectionName);
-    bool unzipDataFile(std::vector<u_int8_t> data, std::vector<u_int8_t> &newData, const char *sectionName);
+    bool dumpFile(const char* confFile, std::vector<u_int8_t>& data, const char* sectionName);
+    bool unzipDataFile(std::vector<u_int8_t> data, std::vector<u_int8_t>& newData, const char* sectionName);
     const char* fwImgTypeToStr(u_int8_t fwImgType);
     FlintStatus UnlockDevice(FwOperations*);
     FlintStatus LockDevice(FwOperations*);
     void ClearGuidStruct(FwOperations::sg_params_t& sgParams);
-    bool stringsCommaSplit(string str, std::vector<u_int32_t> &deviceIds);
+    bool stringsCommaSplit(string str, std::vector<u_int32_t>& deviceIds);
+
 public:
-    SubCommand() : _fwOps(NULL), _imgOps(NULL), _io(NULL), _v(Wtv_Uninitilized), _maxCmdParamNum(-1),  _minCmdParamNum(-1), _mccSupported(false), _imageReactivation(false)
-#ifndef NO_MSTARCHIVE        
-        , _mfa2Pkg(NULL)
+    SubCommand() :
+        _fwOps(NULL),
+        _imgOps(NULL),
+        _io(NULL),
+        _v(Wtv_Uninitilized),
+        _maxCmdParamNum(-1),
+        _minCmdParamNum(-1),
+        _mccSupported(false),
+        _imageReactivation(false)
+#ifndef NO_MSTARCHIVE
+        ,
+        _mfa2Pkg(NULL)
 #endif
     {
         _cmdType = SC_No_Cmd;
@@ -180,16 +204,16 @@ public:
     }
     virtual ~SubCommand();
     virtual FlintStatus executeCommand() = 0;
-    virtual void cleanInterruptedCommand() {}//by default do nothing
-    inline void setParams(const FlintParams& flintParams) {_flintParams = flintParams;}
-    inline string& getName() {return this->_name;}
-    inline string& getDesc() {return this->_desc;}
-    inline string& getExtDesc() {return this->_extendedDesc;}
-    inline string& getFlagL() {return this->_flagLong;}
-    inline string& getFlagS() {return this->_flagShort;}
-    inline string& getParam() {return this->_param;}
-    inline string& getParamExp() {return this->_paramExp;}
-    inline string& getExample() {return this->_example;}
+    virtual void cleanInterruptedCommand() {} // by default do nothing
+    inline void setParams(const FlintParams& flintParams) { _flintParams = flintParams; }
+    inline string& getName() { return this->_name; }
+    inline string& getDesc() { return this->_desc; }
+    inline string& getExtDesc() { return this->_extendedDesc; }
+    inline string& getFlagL() { return this->_flagLong; }
+    inline string& getFlagS() { return this->_flagShort; }
+    inline string& getParam() { return this->_param; }
+    inline string& getParamExp() { return this->_paramExp; }
+    inline string& getExample() { return this->_example; }
 };
 
 class BurnSubCommand : public SubCommand
@@ -204,7 +228,10 @@ private:
     FwCompsMgr* fwCompsAccess;
     FlintStatus burnFs3();
     FlintStatus burnFs2();
-    bool checkFwVersion(bool CreateFromImgInfo = true, u_int16_t fw_ver0 = 0, u_int16_t fw_ver1 = 0, u_int16_t fw_ver2 = 0);
+    bool checkFwVersion(bool CreateFromImgInfo = true,
+                        u_int16_t fw_ver0 = 0,
+                        u_int16_t fw_ver1 = 0,
+                        u_int16_t fw_ver2 = 0);
     bool checkPSID();
     void updateBurnParams();
     bool dealWithExpRom();
@@ -215,8 +242,16 @@ private:
     FlintStatus burnMFA2LiveFish(dm_dev_id_t devid_t);
     FlintStatus burnCongestionControl();
     bool verifyMFA2Params(bool IsLiveFish);
-    FlintStatus BurnLinkX(string deviceName, int deviceIndex, int deviceSize, string binaryFileName, bool linkx_auto_update,
-        bool activationNeeded, bool downloadTransferNeeded, int activate_delay_sec, ProgressCallBackAdvSt* ProgressFuncAdv);
+    FlintStatus BurnLinkX(string deviceName,
+                          int deviceIndex,
+                          int deviceSize,
+                          string binaryFileName,
+                          bool linkx_auto_update,
+                          bool activationNeeded,
+                          bool downloadTransferNeeded,
+                          int activate_delay_sec,
+                          ProgressCallBackAdvSt* ProgressFuncAdv);
+
 public:
     BurnSubCommand();
     ~BurnSubCommand();
@@ -235,6 +270,7 @@ private:
     bool _devQueryRes;
     int _unknownProgress; // used to trace the progress of unknown progress.
     FlintStatus compareMFA2();
+
 public:
     BinaryCompareSubCommand();
     ~BinaryCompareSubCommand();
@@ -254,7 +290,13 @@ private:
     bool checkMac(u_int64_t mac, string& warrStr);
     FlintStatus queryMFA2();
     void AddTableHeaderForCSVFormat(string& outputString);
-    bool PrintLinkXQuery(string& outputString, const string& host, int deviceIndex, const comp_status_st& ComponentStatus, const component_linkx_st& linkx_data, char* delimeter, bool isCSV);
+    bool PrintLinkXQuery(string& outputString,
+                         const string& host,
+                         int deviceIndex,
+                         const comp_status_st& ComponentStatus,
+                         const component_linkx_st& linkx_data,
+                         char* delimeter,
+                         bool isCSV);
     FlintStatus QueryLinkX(string deviceName, string outputFile, std::vector<int> deviceIds);
 
 public:
@@ -341,7 +383,6 @@ public:
 class VerifySubCommand : public SubCommand
 {
 private:
-
 public:
     VerifySubCommand();
     ~VerifySubCommand();
@@ -361,6 +402,7 @@ public:
 class SwResetSubCommand : public SubCommand
 {
 private:
+    bool IsDeviceSupported(dm_dev_id_t dev_id);
 
 public:
     SwResetSubCommand();
@@ -375,11 +417,12 @@ private:
     fw_info_t _info;
     roms_info_t _romsInfo;
     FImage _fRom;
+
 public:
     BromSubCommand();
     ~BromSubCommand();
     inline FlintStatus executeCommand();
-    bool getExpRomStrVer(roms_info_t& roms_info, char *version);
+    bool getExpRomStrVer(roms_info_t& roms_info, char* version);
 };
 
 class DromSubCommand : public SubCommand
@@ -394,7 +437,6 @@ public:
 class RromSubCommand : public SubCommand
 {
 private:
-
 public:
     RromSubCommand();
     ~RromSubCommand();
@@ -405,7 +447,6 @@ public:
 class BbSubCommand : public SubCommand
 {
 private:
-
 public:
     BbSubCommand();
     ~BbSubCommand();
@@ -417,13 +458,14 @@ class SgSubCommand : public SubCommand
 {
 private:
     fw_info_t _info;
-    FwOperations *_ops;
+    FwOperations* _ops;
     FwOperations::sg_params_t _sgParams;
 
     FlintStatus sgFs2();
     FlintStatus sgFs3();
     void setUserGuidsAndMacs();
     bool CheckSetGuidsFlags();
+
 public:
     SgSubCommand();
     ~SgSubCommand();
@@ -436,7 +478,8 @@ class SmgSubCommand : public SubCommand
 private:
     fs3_uid_t _baseGuid;
     fw_info_t _info;
-    FwOperations *_ops;
+    FwOperations* _ops;
+
 public:
     SmgSubCommand();
     ~SmgSubCommand();
@@ -444,20 +487,25 @@ public:
     inline bool verifyParams();
 };
 
+class SetCertChainSubCommand : public SubCommand
+{
+public:
+    SetCertChainSubCommand();
+    ~SetCertChainSubCommand(){};
+    FlintStatus executeCommand();
+};
+
 class SetVpdSubCommand : public SubCommand
 {
-private:
-
 public:
     SetVpdSubCommand();
-    ~SetVpdSubCommand();
+    ~SetVpdSubCommand(){};
     FlintStatus executeCommand();
 };
 
 class SvSubCommand : public SubCommand
 {
 private:
-
 public:
     SvSubCommand();
     ~SvSubCommand();
@@ -476,6 +524,7 @@ class DcSubCommand : public SubCommand
 {
 private:
     std::vector<u_int8_t> _sect;
+
 public:
     DcSubCommand();
     ~DcSubCommand();
@@ -486,6 +535,7 @@ class DhSubCommand : public SubCommand
 {
 private:
     std::vector<u_int8_t> _sect;
+
 public:
     DhSubCommand();
     ~DhSubCommand();
@@ -499,6 +549,7 @@ private:
     hw_key_t _userKey;
     bool _getKeyInter;
     bool getKeyInteractively();
+
 public:
     SetKeySubCommand();
     ~SetKeySubCommand();
@@ -510,6 +561,7 @@ class HwAccessSubCommand : public SubCommand
 private:
     FlintStatus disableHwAccess();
     FlintStatus enableHwAccess();
+
 public:
     HwAccessSubCommand();
     ~HwAccessSubCommand();
@@ -521,6 +573,7 @@ class HwSubCommand : public SubCommand
 {
 private:
     FlintStatus printAttr(const ext_flash_attr_t& attr);
+
 public:
     HwSubCommand();
     ~HwSubCommand();
@@ -530,7 +583,6 @@ public:
 class EraseSubCommand : public SubCommand
 {
 private:
-
 public:
     EraseSubCommand();
     ~EraseSubCommand();
@@ -539,7 +591,6 @@ public:
 class RwSubCommand : public SubCommand
 {
 private:
-
 public:
     RwSubCommand();
     ~RwSubCommand();
@@ -548,7 +599,6 @@ public:
 class WwSubCommand : public SubCommand
 {
 private:
-
 public:
     WwSubCommand();
     ~WwSubCommand();
@@ -558,7 +608,6 @@ public:
 class WwneSubCommand : public SubCommand
 {
 private:
-
 public:
     WwneSubCommand();
     ~WwneSubCommand();
@@ -568,19 +617,20 @@ public:
 class WbSubCommand : public SubCommand
 {
 private:
-    bool extractData(const std::vector<string>& cmdParams, u_int32_t *addr, std::vector<u_int8_t>& data);
+    bool extractData(const std::vector<string>& cmdParams, u_int32_t* addr, std::vector<u_int8_t>& data);
+
 public:
     WbSubCommand();
     ~WbSubCommand();
     FlintStatus executeCommand();
 };
 
-
 class WbneSubCommand : public SubCommand
 {
 private:
-    bool extractData(const std::vector<string>& cmdParams, u_int32_t *addr, std::vector<u_int32_t>& data);
+    bool extractData(const std::vector<string>& cmdParams, u_int32_t* addr, std::vector<u_int32_t>& data);
     bool writeBlock(u_int32_t addr, std::vector<u_int32_t> dataVec);
+
 public:
     WbneSubCommand();
     ~WbneSubCommand();
@@ -590,8 +640,9 @@ public:
 class RbSubCommand : public SubCommand
 {
 private:
-    bool printToScreen(const std::vector<u_int8_t>& buff);
+    bool printToScreen(const std::vector<u_int8_t>& buff, bool hexdump_format);
     bool readBlock(u_int32_t addr, std::vector<u_int8_t>& buff, bool isFlash);
+
 public:
     RbSubCommand();
     ~RbSubCommand();
@@ -601,7 +652,6 @@ public:
 class ClearSemSubCommand : public SubCommand
 {
 private:
-
 public:
     ClearSemSubCommand();
     ~ClearSemSubCommand();
@@ -612,6 +662,7 @@ class RomQuerySubCommand : public SubCommand
 {
 private:
     roms_info_t _romsInfo;
+
 public:
     RomQuerySubCommand();
     ~RomQuerySubCommand();
@@ -640,6 +691,7 @@ public:
     CheckSumSubCommand();
     ~CheckSumSubCommand();
     FlintStatus executeCommand();
+
 private:
     bool extractChecksumFromStr(string str, u_int8_t checkSum[16]);
     string checkSum2Str(u_int8_t checkSum[16]);
@@ -652,8 +704,10 @@ public:
     TimeStampSubCommand();
     ~TimeStampSubCommand();
     FlintStatus executeCommand();
+
 private:
-    enum {
+    enum
+    {
         TS_No_Command,
         TS_Query,
         TS_Set,
@@ -671,7 +725,7 @@ private:
     bool resetTs();
 
     int _operation;
-    FwOperations *_ops;
+    FwOperations* _ops;
     struct tools_open_ts_entry _userTsEntry;
     struct tools_open_fw_version _userFwVer;
 };
