@@ -1,5 +1,6 @@
 /*
  * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -28,8 +29,9 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
  */
- 
+
 #ifndef USER_MLXFWOPS_LIB_FW_ABSTRACT_COMP_ACCESS_H_
 #define USER_MLXFWOPS_LIB_FW_ABSTRACT_COMP_ACCESS_H_
 
@@ -38,26 +40,27 @@
 class AbstractComponentAccess
 {
 public:
-    virtual bool accessComponent(u_int32_t updateHandle, u_int32_t offset,
-        u_int32_t size,
-        u_int32_t data[],
-        access_type_t access,
-        const char* currComponentStr,
-        ProgressCallBackAdvSt *progressFuncAdv) = 0;
+    virtual bool accessComponent(u_int32_t updateHandle,
+                                 u_int32_t offset,
+                                 u_int32_t size,
+                                 u_int32_t data[],
+                                 access_type_t access,
+                                 const char* currComponentStr,
+                                 ProgressCallBackAdvSt* progressFuncAdv) = 0;
 
-    virtual fw_comps_error_t  getLastFirmwareError() = 0;
-    virtual reg_access_status_t  getLastRegisterAccessStatus() = 0;
+    virtual fw_comps_error_t getLastFirmwareError() = 0;
+    virtual reg_access_status_t getLastRegisterAccessStatus() = 0;
 
-    AbstractComponentAccess(FwCompsMgr* Manager, mfile *Mf)
+    AbstractComponentAccess(FwCompsMgr* manager, mfile* mf)
     {
-        _mf = Mf;
-        _manager = Manager;
+        _mf = mf;
+        _manager = manager;
         _lastFwError = FWCOMPS_SUCCESS;
     }
     virtual ~AbstractComponentAccess() {}
 
 protected:
-    mfile *_mf;
+    mfile* _mf;
     FwCompsMgr* _manager;
     fw_comps_error_t _lastFwError;
     reg_access_status_t _lastRegisterAccessStatus;
@@ -66,12 +69,12 @@ protected:
 class ComponentAccessFactory
 {
 public:
-    AbstractComponentAccess* createDataAccessObject(FwCompsMgr* manager, mfile *Mf, bool isMCDDRegisterSupported);
-    static ComponentAccessFactory* GetInstance() {
+    AbstractComponentAccess* createDataAccessObject(FwCompsMgr* manager, mfile* mf, bool isMCDDRegisterSupported);
+    static ComponentAccessFactory* GetInstance()
+    {
         static ComponentAccessFactory myObj;
         return &myObj;
     }
 };
 
-
 #endif
