@@ -1,5 +1,6 @@
 /*
  * Copyright (C) Jan 2006 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -31,9 +32,6 @@
  *
  */
 
-
-
-
 #ifndef __MLXFWMANAGER_COMMON_H__
 #define __MLXFWMANAGER_COMMON_H__
 
@@ -48,7 +46,6 @@
 #include <sys/stat.h>
 #include <string>
 #include <vector>
-#include <boost/algorithm/string.hpp>
 #include <tools_dev_types.h>
 #include <mlxfwops.h>
 #include <mlxfwops_com.h>
@@ -59,37 +56,44 @@
 #include "err_msgs.h"
 
 #ifndef NO_ZLIB
-    #include <zlib.h>
+#include <zlib.h>
 #endif
 
-
 #if defined(__WIN__)
 #include <process.h>
 #include <io.h>
-const char* SafeGetEnv(const char *var);
+#ifdef _MSC_VER
+typedef int mode_t;
+#endif
+const char* SafeGetEnv(const char* var);
 #define TMP_DIR SafeGetEnv("TEMP")
 #define PATH_SEPARATOR "\\"
 #define GetCurrDir(sz, buf) GetCurrentDirectory(sz, buf)
 #else
-#define TMP_DIR  "/tmp"
+#define TMP_DIR "/tmp"
 #define PATH_SEPARATOR "/"
 #define GetCurrDir(sz, buf) getcwd(buf, sz)
 #endif
 
-
 using namespace std;
 
 inline string getLogDir(string toolName)
 {
-    #if defined(__WIN__)
+#if defined(__WIN__)
     (void)toolName;
     return TMP_DIR;
-    #else
+#else
     return (string) "/tmp/" + toolName + "_workdir";
-    #endif
+#endif
 }
-namespace mlxFWMSetupType {
-enum T {normal, lvim, dl};
+namespace mlxFWMSetupType
+{
+enum T
+{
+    normal,
+    lvim,
+    dl
+};
 };
 
 inline string int_to_string(int num)
@@ -100,26 +104,26 @@ inline string int_to_string(int num)
 }
 
 string getErrStr(int rc);
-int    mapRetValue(int rc, mlxFWMSetupType::T setupType);
+int mapRetValue(int rc, mlxFWMSetupType::T setupType);
 string beautify_device_name(string family);
-int    CreateTempDir(string tempDir, string& tempBaseDir);
-int    my_chmod(const char *path, mode_t mode);
-int    RemoveDir(const string &dir);
+int CreateTempDir(string tempDir, string& tempBaseDir);
+int my_chmod(const char* path, mode_t mode);
+int RemoveDir(const string& dir);
 
-bool   unzipDataFile(std::vector<u_int8_t> data,
-                     std::vector<u_int8_t> &newData, const char *sectionName);
-int  MkDir(const string dir);
+bool unzipDataFile(std::vector<u_int8_t> data, std::vector<u_int8_t>& newData, const char* sectionName);
+int MkDir(const string dir);
 
 #if defined(__WIN__)
-int  ForceMkDir(const string dir);
-void FixPath(string &s);
-int mlxfw_replace(char *st, char *orig, char *repl);
-int mlxfw_get_exec_name_from_path(char *str, char *exec_name);
-    #define mlxfw_MTCR_DLL_NAME "libmtcr-1.dll"
+int ForceMkDir(const string dir);
+void FixPath(string& s);
+int mlxfw_replace(char* st, char* orig, char* repl);
+int mlxfw_get_exec_name_from_path(char* str, char* exec_name);
+#define mlxfw_MTCR_DLL_NAME "libmtcr-1.dll"
 static const mode_t MS_MODE_MASK = 0x0000ffff;
 #endif
 
-class DownloadedFileProperties {
+class DownloadedFileProperties
+{
 public:
     string url;
     string name;
@@ -131,4 +135,3 @@ public:
 };
 
 #endif
-
