@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Jan 2019 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2019-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -38,13 +38,15 @@
 #include "mlxlink_commander.h"
 #include "printutil/mlxlink_record.h"
 
-class MlxlinkUi : public CommandLineRequester {
+class MlxlinkUi : public CommandLineRequester
+{
 public:
     MlxlinkUi();
     virtual ~MlxlinkUi();
-    int run(int argc, char **argv);
+    int run(int argc, char** argv);
 
 protected:
+    virtual void addCmd(OPTION_TYPE option);
     virtual ParseStatus HandleOption(string name, string value);
     virtual void printSynopsisHeader();
     virtual void printSynopsisQueries();
@@ -57,6 +59,7 @@ protected:
     virtual void validatePCIeParams();
     virtual void validateGeneralCmdsParams();
     virtual void validatePRBSParams();
+    virtual void validateModulePRBSParams();
     virtual void validateSpeedAndCSVBerParams();
     virtual void validateCableParams();
     virtual void validateTxGroupParams();
@@ -68,6 +71,6 @@ protected:
 
     CommandLineParser _cmdParser;
     std::vector<OPTION_TYPE> _sendRegFuncMap;
-    MlxlinkCommander *_mlxlinkCommander;
+    MlxlinkCommander* _mlxlinkCommander;
 };
 #endif /* MLXLINK_UI_H */
