@@ -1,5 +1,6 @@
 
 # Copyright (c) 2004-2010 Mellanox Technologies LTD. All rights reserved.
+# Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 #
 # This software is available to you under a choice of one of two
 # licenses.  You may choose to be licensed under the terms of the GNU
@@ -28,41 +29,51 @@
 # ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-#--
+# --
 
 import os
 import sys
 import platform
 import ctypes
+import struct
+
 
 def ones(n):
     return (1 << n) - 1
 
+
 def extractField(val, start, size):
-    return (val & (ones(size)<<start)) >> start
+    return (val & (ones(size) << start)) >> start
+
 
 def insertField(val1, start1, val2, start2, size):
-    return val1 & ~(ones(size)<<start1) | (extractField(val2, start2, size) << start1)
+    return val1 & ~(ones(size) << start1) | (extractField(val2, start2, size) << start1)
+
 
 class MtcrException(Exception):
     pass
 
+
 class CmdIfException(Exception):
     pass
 
+
 ##########################
 CMTCR = None
 try:
     from ctypes import *
     ctypes.CDLL._func_restype_ = ctypes.c_ulonglong
     if platform.system() == "Windows" or os.name == "nt":
-        CMTCR = CDLL(".\\libmtcr-1.dll", use_errno=True)
+        try:
+            CMTCR = CDLL("libmtcr-1.dll", use_errno=True)
+        except BaseException:
+            CMTCR = CDLL(os.path.join(os.path.dirname(os.path.realpath(__file__)), "libmtcr-1.dll"), use_errno=True)
     else:
         try:
             CMTCR = CDLL("cmtcr.so", use_errno=True)
-        except:
+        except BaseException:
             CMTCR = CDLL(os.path.join(os.path.dirname(os.path.realpath(__file__)), "cmtcr.so"), use_errno=True)
-except:
+except BaseException:
     CMTCR = None
 
 if CMTCR:
@@ -93,13 +104,13 @@ if CMTCR:
 
         def is_cable(self):
             return '_cable' in str(self.mdev)
-        
+
         def is_linkx(self):
             return '_lx' in str(self.mdev)
 
         def open(self):
             if self.is_cable() or self.is_linkx():
-                self.mf = ctypes.c_void_p(self.mopenFuncAdv(self.mdev,0xffffffff))
+                self.mf = ctypes.c_void_p(self.mopenFuncAdv(self.mdev, 0xffffffff))
             else:
                 self.mf = ctypes.c_void_p(self.mopenFunc(self.mdev))
 
@@ -107,8 +118,6 @@ if CMTCR:
                 error = os.strerror(ctypes.get_errno())
                 raise MtcrException("Failed to re-open device (%s): %s" % (self.mdev.decode("utf-8"), error))
 
-
-
         ##########################
         def __del__(self):
             self.close()
@@ -139,9 +148,9 @@ if CMTCR:
             self.write4(addr, newVal)
 
         ##########################
-        def read4Block(self, addr, size): # size in dwords
+        def read4Block(self, addr, size):  # size in dwords
             dataArr = (c_uint32 * size)()
-            if self.mread4BlockFunc(self.mf, addr, cast(dataArr, POINTER(c_uint32)), size*4) !=  size*4:
+            if self.mread4BlockFunc(self.mf, addr, cast(dataArr, POINTER(c_uint32)), size * 4) != size * 4:
                 raise MtcrException("Failed to read block from mst device from address 0x%x of size %d bytes" % (addr, size))
             return list(dataArr)
 
@@ -149,33 +158,39 @@ if CMTCR:
         def write4Block(self, addr, dataList):
             size = len(dataList)
             dataArr = (c_uint32 * size)(*dataList)
-            if self.mwrite4BlockFunc(self.mf, addr, cast(dataArr, POINTER(c_uint32)), size*4) !=  size*4:
+            if self.mwrite4BlockFunc(self.mf, addr, cast(dataArr, POINTER(c_uint32)), size * 4) != size * 4:
                 raise MtcrException("Failed to write block to mst device to address 0x%x of size %d bytes" % (addr, size))
-            
+
         ##########################
         def icmdSendCmd(self, opcode, data, skipWrite):
             dataArr = (c_uint8 * len(data))(*data)
             rc = self.icmdSendCommandFunc(self.mf, opcode, cast(dataArr, POINTER(c_uint8)), len(data), skipWrite)
+
+            # data can also be used as output so need to convert back from dataArr.
+            for i, x in enumerate(dataArr):
+                data[i] = dataArr[i]
             if rc:
                 raise CmdIfException("Failed to send command")
         ##########################
         def mHcaReset(self, dbdf_list):
-                
+
             bus_array_size = len(dbdf_list)
 
             bus_array = (ctypes.c_ulong * bus_array_size)()
-            
+
             # Extract the bus value from the dbdf list.
-            for idx,dbdf in enumerate(dbdf_list):
+            for idx, dbdf in enumerate(dbdf_list):
                 bus_array[idx] = int(dbdf[5:7], 16)
 
             if self.mHcaResetFunc(self.mf, bus_array, bus_array_size) != 0:
                 raise MtcrException("Failed to reset device")
+        ##########################
+
 
 else:
     import subprocess
     import string
-    
+
     def getstatusoutput(cmd):
         pipe = subprocess.Popen(cmd, shell=False, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         cout = pipe.stdout
@@ -228,22 +243,22 @@ else:
             self.write4(addr, newVal)
 
         ##########################
-        def read4Block(self, addr, size): # size in dwords
+        def read4Block(self, addr, size):  # size in dwords
             l = []
-            for add in range(addr, addr + size*4, 4):
+            for add in range(addr, addr + size * 4, 4):
                 l.append(self.read4(add))
             return l
 
         ##########################
         def write4Block(self, addr, dataList):
             size = len(dataList)
-            for i, current_addr in enumerate(range(addr, addr + size*4, 4)):
+            for i, current_addr in enumerate(range(addr, addr + size * 4, 4)):
                 self.write4(current_addr, dataList[i])
-        
-        ##########################   
+
+        ##########################
         def icmdSendCmd(self, opcode, data, skipWrite):
             raise MtcrException("icmd isn't supported in MCRA mode")
 
-        ##########################   
+        ##########################
         def mHcaReset(self, dbdf_list):
             raise MtcrException("mswReset isn't supported in MCRA mode")
