@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2020-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -48,40 +48,45 @@
 #include "pldm_component_image.h"
 #include "pldm_pkg.h"
 
-const u_int8_t PldmPkg::UUID[] = {0xF0, 0x18, 0x87, 0x8C, 0xCB, 0x7D, 0x49,
-            0x43, 0x98, 0x00, 0xA0, 0x2F, 0x05, 0x9A, 0xCA, 0x02};
+const u_int8_t PldmPkg::UUID[] = {0xF0, 0x18, 0x87, 0x8C, 0xCB, 0x7D, 0x49, 0x43,
+                                  0x98, 0x00, 0xA0, 0x2F, 0x05, 0x9A, 0xCA, 0x02};
 
-PldmPkg::PldmPkg(): deviceIDRecordCount(0) {
-}
+PldmPkg::PldmPkg() : deviceIDRecordCount(0) {}
 
-PldmPkg::~PldmPkg() {
-    while(!deviceIDRecords.empty()) {
+PldmPkg::~PldmPkg()
+{
+    while (!deviceIDRecords.empty())
+    {
         delete deviceIDRecords.back();
         deviceIDRecords.pop_back();
     }
-    while(!componentImages.empty()) {
+    while (!componentImages.empty())
+    {
         delete componentImages.back();
         componentImages.pop_back();
     }
 }
 
-bool PldmPkg::unpack(PldmBuffer & buff) {
-    if(!packageHeader.unpack(buff)) {
+bool PldmPkg::unpack(PldmBuffer& buff)
+{
+    if (!packageHeader.unpack(buff))
+    {
         return false;
     }
     buff.read(deviceIDRecordCount);
-    u_int8_t componentBitmapBitLength = \
-            packageHeader.getComponentBitmapBitLength();
+    u_int8_t componentBitmapBitLength = packageHeader.getComponentBitmapBitLength();
     u_int8_t i;
-    for(i=0; i< deviceIDRecordCount; i++) {
-        PldmDevIdRecord * deviceIDRecord = new PldmDevIdRecord(componentBitmapBitLength);
+    for (i = 0; i < deviceIDRecordCount; i++)
+    {
+        PldmDevIdRecord* deviceIDRecord = new PldmDevIdRecord(componentBitmapBitLength);
         deviceIDRecord->unpack(buff);
         deviceIDRecords.push_back(deviceIDRecord);
         psidImageMap[deviceIDRecord->getDevicePsid()] = deviceIDRecord->getComponentImageIndex();
     }
     buff.read(componentImageCount);
-    for(i=0; i< componentImageCount; i++) {
-        PldmComponenetImage * componentImage = new PldmComponenetImage();
+    for (i = 0; i < componentImageCount; i++)
+    {
+        PldmComponenetImage* componentImage = new PldmComponenetImage();
         componentImage->unpack(buff);
         componentImages.push_back(componentImage);
     }
@@ -89,30 +94,33 @@ bool PldmPkg::unpack(PldmBuffer & buff) {
     return true;
 }
 
-
-void PldmPkg::print(FILE * fp) {
+void PldmPkg::print(FILE* fp)
+{
     fprintf(fp, "packageHeader:\n");
     packageHeader.print(fp);
     fprintf(fp, "deviceIDRecordCount: 0x%X\n", deviceIDRecordCount);
     u_int8_t i;
-    for(i=0; i< deviceIDRecordCount; i++) {
+    for (i = 0; i < deviceIDRecordCount; i++)
+    {
         fprintf(fp, "deviceIDRecords[%d]:\n", i);
         deviceIDRecords[i]->print(fp);
     }
     fprintf(fp, "componentImageCount: 0x%X\n", componentImageCount);
-    for(i=0; i< componentImageCount; i++) {
+    for (i = 0; i < componentImageCount; i++)
+    {
         fprintf(fp, "componentImages[%d]:\n", i);
         componentImages[i]->print(fp);
     }
     fprintf(fp, "packageHeaderChecksum: 0x%X\n", packageHeaderChecksum);
 }
 
-const PldmComponenetImage * PldmPkg::getImageByPsid(const std::string & psid) const {
+const PldmComponenetImage* PldmPkg::getImageByPsid(const std::string& psid) const
+{
     PsidImageMap::const_iterator it = psidImageMap.find(psid);
     if (it == psidImageMap.end())
         return NULL;
     int location = it->second;
-    if(location == -1 || location >= componentImageCount)
+    if (location == -1 || location >= componentImageCount)
         return NULL;
     return componentImages[location];
 }
